@@ -7,6 +7,7 @@
 !      2002/02/07  ݹ  ؿ,ѿ̾ѹ
 !      2002/03/25  ݹ  ⥸塼̾ѹ
 !      2002/05/25  ݹ  ʻɸ̤٤̿̾ˡѹ
+!      2002/10/07  ݹ  , ̺ɸʬɲ
 !
 !         Ѵʻǡ, ڥȥǡ礭Ϸᤦ
 !
@@ -32,6 +33,8 @@ module w_module
   public w_DivLon_xy, w_DivLat_xy             ! ȯʬ
   public w_Div_xy_xy                          ! ȯʬ
   public w_Jacobian_w_w                       ! 䥳ӥ
+  public xy_GradLambda_w, xy_GradMu_w         ! ۷ʬ(,̺ɸ)
+  public w_DivLambda_xy, w_DivMu_xy           ! ȯʬ(,̺ɸ)
 
   public IntLonLat_xy                         ! ٷʬ
   public y_IntLon_xy, IntLon_x                ! ʬ    
