@@ -7,6 +7,7 @@
 !      2002/02/07  ݹ  ؿ,ѿ̾ѹ
 !      2002/03/25  ݹ  ⥸塼̾ѹ
 !      2002/05/25  ݹ  ʻɸ̤٤̿̾ˡѹ
+!      2002/10/07  ݹ  , ̺ɸʬɲ
 !
 !         Ѵʻǡ, ڥȥǡ礭Ϸᤦ
 !
@@ -35,6 +36,8 @@ module wa_module
   public w_DivLon_xy, w_DivLat_xy             ! ȯʬ
   public w_Div_xy_xy                          ! ȯʬ
   public w_Jacobian_w_w                       ! 䥳ӥ
+  public xy_GradLambda_w, xy_GradMu_w         ! ۷ʬ(,̺ɸ)
+  public w_DivLambda_xy, w_DivMu_xy           ! ȯʬ(,̺ɸ)
 
   public wa_Lapla_wa, wa_LaplaInv_wa          ! ץ饷ȵձ黻
   public wa_DLon_wa                           ! ʬ
@@ -42,6 +45,8 @@ module wa_module
   public wa_DivLon_xya, wa_DivLat_xya         ! ȯʬ
   public wa_Div_xya_xya                       ! ȯʬ
   public wa_Jacobian_wa_wa                    ! 䥳ӥ
+  public xya_GradLambda_wa, xya_GradMu_wa     ! ۷ʬ(,̺ɸ)
+  public wa_DivLambda_xya, wa_DivMu_xya       ! ȯʬ(,̺ɸ)
 
   public IntLonLat_xy                         ! ٷʬ
   public y_IntLon_xy, IntLon_x                ! ʬ    
